import unittest
import os

from unittest.mock import patch

from ansibleconnect.tmuxpresenter import tmux_start_command, ssh_auth_socket_env_var_command


class TestTmuxPresenter(unittest.TestCase):

    def test_tmux_start_command_starts_with_tmux_new_window_when_in_tmux(self):
        os.environ.setdefault("TMUX", "1")
        start_command = tmux_start_command()
        self.assertIn("tmux new-window", start_command)

    def test_tmux_start_command_starts_with_tmux_new_session_when_not_in_tmux(self):
        os.environ.clear()
        start_command = tmux_start_command()
        self.assertIn("tmux new-session", start_command)

    @patch.dict(os.environ, {'SSH_AUTH_SOCK': '/test/auth_sock'})
    def test_ssh_auth_sock_exported_when_env_var_set(self):
        expected_auth_sock_command = 'export SSH_AUTH_SOCK=/test/auth_sock'
        result_auth_sock_command = ssh_auth_socket_env_var_command()
        self.assertEqual(expected_auth_sock_command, result_auth_sock_command)

    def test_ssh_auth_sock_command_empty_when_env_var_not_set(self):
        if "SSH_AUTH_SOCK" in os.environ:
            os.environ.pop("SSH_AUTH_SOCK")
        expected_auth_sock_command = ''
        result_auth_sock_command = ssh_auth_socket_env_var_command()
        self.assertEqual(expected_auth_sock_command, result_auth_sock_command)



import unittest
import os

from parameterized import parameterized

from ansibleconnect.inventoryadapter import InventoryAdapter

TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), 'files')
TEST_INVENTORY_FILE = os.path.join(TEST_DATA_DIR, 'inventory.yml')


class TestInventoryAdapter(unittest.TestCase):
    def setUp(self) -> None:
        self.inventory_adapter = InventoryAdapter(TEST_INVENTORY_FILE)
        self.all_hosts = self.inventory_adapter._inventory.hosts.values()

    def test_get_hosts_by_group_returns_all_hosts_when_empty_lists_are_given(self):
        output_hosts = self.inventory_adapter.get_hosts_by_group([], [])
        self.assertEqual(8, len(output_hosts))

    def test_get_hosts_by_group_returns_hosts_only_from_the_given_group(self):
        output_hosts = self.inventory_adapter.get_hosts_by_group(['groupA'], [])
        self.assertEqual(3, len(output_hosts))

    def test_get_hosts_by_names(self):
        output_hosts = self.inventory_adapter.get_hosts_by_names(['10.0.0.5',
                                                                  '172.16.0.30',
                                                                  '192.168.0.2'])
        self.assertEqual(3, len(output_hosts))

    def test_get_hosts_by_variables_empty_vars_no_vars(self):
        output_hosts = self.inventory_adapter.get_hosts_by_variables(hosts=self.all_hosts,
                                                                     variables=[],
                                                                     no_variables=[])
        self.assertEqual(8, len(output_hosts))

    @parameterized.expand([
        ([('deploy', True)], 2),
        ([('myname', None)], 3),
        ([('myname', 'Dhost1'), ('hostvar', None)], 4)
    ])
    def test_get_hosts_by_variables_non_empty_vars_empty_no_vars(self, test_arg, expected_len):
        output_hosts = self.inventory_adapter.get_hosts_by_variables(hosts=self.all_hosts,
                                                                     variables=test_arg,
                                                                     no_variables=[])
        self.assertEqual(expected_len, len(output_hosts))

    @parameterized.expand([
        ([('deploy', True)], 6),
        ([('myname', None)], 5),
        ([('myname', 'Dhost1'), ('hostvar', None)], 4)
    ])
    def test_get_hosts_by_variables_empty_vars_non_empty_no_vars(self, test_arg, expected_len):
        output_hosts = self.inventory_adapter.get_hosts_by_variables(hosts=self.all_hosts,
                                                                     variables=[],
                                                                     no_variables=test_arg)
        self.assertEqual(expected_len, len(output_hosts))

    @parameterized.expand([
        ([('deploy', True)], [('myname', 'Dhost1')], 1),
        ([('hostvar', None)], [('hostvar', 'test')], 1)
    ])
    def test_get_hosts_by_variables_non_empty_vars_no_vars(self, var, no_var, expected_len):
        output_hosts = self.inventory_adapter.get_hosts_by_variables(hosts=self.all_hosts,
                                                                     variables=var,
                                                                     no_variables=no_var)
        self.assertEqual(expected_len, len(output_hosts))



import unittest
import os

from unittest.mock import Mock, patch

from ansibleconnect.ansible_config_adapter import get_dict_of_ansible_config_options

TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), 'files')
TEST_ANSIBLE_CFG = os.path.join(TEST_DATA_DIR, 'test_ansible_config.cfg')


class TestGetDictOfAnsibleConfigOptions(unittest.TestCase):
    @patch('ansibleconnect.ansible_config_adapter.get_ansible_config_filepath',
           Mock(return_value=TEST_ANSIBLE_CFG))
    def test_options_from_all_sections_are_put_as_dict_items(self):
        expected_dict = {'private_key_file': 'test_key_file',
                         'ssh_args': 'test_arg',
                         'test': 'option'}
        result_dict = get_dict_of_ansible_config_options()
        self.assertDictEqual(expected_dict, result_dict)
